@@ -8,7 +8,9 @@
 #define _FCITX_MODULES_QUICKPHRASE_QUICKPHRASE_PUBLIC_H_
 
 #include <functional>
+#include <memory>
 #include <string>
+#include <fcitx-utils/handlertable.h>
 #include <fcitx-utils/key.h>
 #include <fcitx-utils/metastring.h>
 #include <fcitx/addoninstance.h>
@@ -22,13 +24,22 @@ enum class QuickPhraseAction {
     DigitSelection,
     AlphaSelection,
     NoneSelection,
-    DoNothing
+    DoNothing,
+    AutoCommit,
 };
 
 using QuickPhraseAddCandidateCallback = std::function<void(
     const std::string &, const std::string &, QuickPhraseAction action)>;
-using QuickPhraseProviderCallback = std::function<bool(
-    InputContext *ic, const std::string &, QuickPhraseAddCandidateCallback)>;
+using QuickPhraseProviderCallback =
+    std::function<bool(InputContext *ic, const std::string &,
+                       const QuickPhraseAddCandidateCallback &)>;
+
+using QuickPhraseAddCandidateCallbackV2 =
+    std::function<void(const std::string &, const std::string &,
+                       const std::string &, QuickPhraseAction action)>;
+using QuickPhraseProviderCallbackV2 =
+    std::function<bool(InputContext *ic, const std::string &,
+                       const QuickPhraseAddCandidateCallbackV2 &)>;
 
 } // namespace fcitx
 
@@ -39,10 +50,17 @@ FCITX_ADDON_DECLARE_FUNCTION(QuickPhrase, trigger,
                                   const std::string &prefix,
                                   const std::string &str,
                                   const std::string &alt, const Key &key));
+FCITX_ADDON_DECLARE_FUNCTION(QuickPhrase, setBuffer,
+                             void(InputContext *ic, const std::string &text));
 
 FCITX_ADDON_DECLARE_FUNCTION(
     QuickPhrase, addProvider,
     std::unique_ptr<HandlerTableEntry<QuickPhraseProviderCallback>>(
         QuickPhraseProviderCallback));
 
+FCITX_ADDON_DECLARE_FUNCTION(
+    QuickPhrase, addProviderV2,
+    std::unique_ptr<HandlerTableEntry<QuickPhraseProviderCallbackV2>>(
+        QuickPhraseProviderCallbackV2));
+
 #endif // _FCITX_MODULES_QUICKPHRASE_QUICKPHRASE_PUBLIC_H_
